@@ -170,6 +170,7 @@ k = Project(typ='R2')
 k.createSurvey(testdir + 'dc-2d/syscal.csv')
 #k.createMesh('quad', surface=np.array([[0, 0, 1], [3, 0, 1]]))
 k.createMesh('trian')
+# external_nodes,surface_flag = k.mesh.externalNodes() # comment as this requires new mesh calc compile 
 k.mesh.computeNeigh()
 rmesh = k.mesh.refine()
 #k.mesh.connection = k.mesh.connection.astype(np.int_)
@@ -553,7 +554,7 @@ k.showSlice(axis='x')
 k.showSlice(axis='y')
 k.showPseudoInvError()
 k.showInvError()
-k.saveMeshVtk()
+k.saveMesh()
 print('elapsed: {:.4}s'.format(time.time() - t0))
 timings['dc-3d'] = time.time() - t0
 #timeit k.mesh.orderNodes()
